/*
 * gMapMaker
 * Copyright (C) 2007  Damien Debin
 * http://debin.net/gMapMaker/
 * 
 * This file is part of gMapMaker.
 * 
 * Foobar is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Foobar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Globalization;
using System.Threading;

namespace gMapMaker
{
  public partial class ProgressWindow : Form
  {
    readonly BackgroundWorker worker;
    double progressValue;
    bool cancelled;
    public bool closingAsked;

    public bool Cancelled
    {
      get
      {
        return cancelled;
      }
    }

    public ProgressWindow(BackgroundWorker worker, string phase)
    {
      InitializeComponent();

      this.Cursor = Cursors.Default;
      this.worker = worker;
      this.Text += phase;
    }

    public void SetProgressValue(double inc)
    {
      progressValue += inc;
      progressBar.Value = (int)Math.Round(progressValue * 100.0);
      infoLabel.Text = progressValue.ToString(" 0.0%", MainForm.ciUS.NumberFormat);
    }

    public void SetStatusLabel(string status)
    {
      if (worker.CancellationPending)
      {
        return;
      }

      statusLabel.Text = status + "...";
    }

    private void Cancel()
    {
      cancelled = true;
      cancelButton.Enabled = false;

      if (worker.IsBusy)
      {
        worker.CancelAsync();

        statusLabel.Text = "Cancelling...";

        while (worker.IsBusy)
        {
          Application.DoEvents();
          Thread.Sleep(10);
        }
      }
    }

    private void cancelButton_Click(object sender, EventArgs e)
    {
      Cancel();
      closingAsked = true;
      Close();
    }

    private void ProgressWindow_FormClosing(object sender, FormClosingEventArgs e)
    {
      if (!closingAsked)
      {
        Cancel();
      }
    }
  }
}